<?php

namespace Drupal\editor_note\Controller;

use Drupal\Core\Access\AccessResultInterface;
use Drupal\Core\Access\AccessResult;
use Drupal\Core\Session\AccountInterface;
use Drupal\editor_note\Entity\EditorNote;

/**
 * Checks access for editor note routes.
 *
 * @package Drupal\editor_note\Controller
 */
class EditorNoteController {

  /**
   * Checks access to editor note.
   *
   * @param AccountInterface $account
   *   Current user.
   * @param EditorNote $editor_note
   *   Editor note entity.
   *
   * @return AccessResultInterface
   *   The access result.
   */
  public function accessEditorNote(AccountInterface $account, EditorNote $editor_note = NULL) {
    if (!empty($editor_note)) {
      $note_author = $editor_note->uid->entity;

      if (!empty($note_author) && $note_author->id() == $account->id()) {
        $access_result = AccessResult::allowed();
      }
      else {
        $access_result = AccessResult::allowedIf($account->hasPermission('administer any editor note'));
      }
    }
    else {
      $access_result = AccessResult::forbidden();
    }

    return $access_result;
  }

}
